@@ -1,7 +1,7 @@
 /* sercomm.c
  *
- * Copyright 2001, 2002 Sun Microsystems, Inc.,
- * Copyright 2001, 2002 BAUM Retec, A.G.
+ * Copyright 2001 - 2005 Sun Microsystems, Inc.,
+ * Copyright 2001 - 2005 BAUM Retec, A.G.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -49,40 +49,16 @@ gboolean		 glib_poll = TRUE;
 
 /* Functions */
 gint 
-brl_ser_open_port (gint port)
+brl_ser_open_port (gchar *port)
 {
-	
-    gchar *pname; /* port name */
+    if (!port || !port[0])
+	return 0;
 
-    switch (port)
-    {
-	case 0:
-	    pname = TTYNAME0; 	
-	break;
-    
-	case 1:
-	    pname = TTYNAME1;
-	break;
-	
-	case 2:
-	    pname = TTYNAME2; 	
-	break;
-    
-	case 3:
-	    pname = TTYNAME3;
-	break;
-
-	default:
-	    fprintf (stderr, "\nbrl_open_port: Invalid serial port number %d", port);
-	    return 0;
-	break;
-    }
-
-    fd_serial = open(pname, O_RDWR | O_NOCTTY | O_NDELAY | O_NONBLOCK);		
+    fd_serial = open(port, O_RDWR | O_NOCTTY | O_NDELAY | O_NONBLOCK);		
                    	
     if (fd_serial == -1)
     {
-	fprintf (stderr, "\nbrl_open_port: Unable to open the serial port (%s).", pname);
+	fprintf (stderr, "\nbrl_open_port: Unable to open the serial port (%s).", port);
 	return 0;
     }
 
